
All information will be updated after INISTA 2022


trclip
======


.. image:: https://img.shields.io/pypi/v/trclip.svg
        :target: https://pypi.python.org/pypi/trclip

.. image:: https://img.shields.io/travis/yusufani/trclip.svg
        :target: https://travis-ci.com/yusufani/trclip

.. image:: https://readthedocs.org/projects/trclip/badge/?version=latest
        :target: https://trclip.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A Turkish CLIP


* Free software: MIT license
* Documentation: https://trclip.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
